@@ -601,7 +601,7 @@ int cmd_listall ( int argc, char ** argv, struct mpd_connection *conn )
 			if (!mpd_send_list_all_meta(conn, listall))
 				printErrorAndExit(conn);
 
-			print_entity_list(conn);
+			print_entity_list(conn, MPD_ENTITY_TYPE_UNKNOWN);
 		} else {
 			if (!mpd_send_list_all(conn, listall))
 				printErrorAndExit(conn);
@@ -688,7 +688,7 @@ int cmd_ls ( int argc, char ** argv, struct mpd_connection *conn )
 		if (!mpd_send_list_meta(conn, ls))
 			printErrorAndExit(conn);
 
-		print_entity_list(conn);
+		print_entity_list(conn, MPD_ENTITY_TYPE_UNKNOWN);
 		my_finishCommand(conn);
 
 	} while (++i < argc && (ls = charset_to_utf8(argv[i])) != NULL);
@@ -707,7 +707,7 @@ int cmd_lsplaylists ( int argc, char ** argv, struct mpd_connection *conn )
 		if (!mpd_send_list_meta(conn, ls))
 			printErrorAndExit(conn);
 
-		print_entity_list(conn);
+		print_entity_list(conn, MPD_ENTITY_TYPE_PLAYLIST);
 		my_finishCommand(conn);
 
 	} while (++i < argc && (ls = charset_to_utf8(argv[i])) != NULL);
@@ -731,6 +731,25 @@ int cmd_load ( int argc, char ** argv, struct mpd_connection *conn )
 	return 0;
 }
 
+int cmd_insert (int argc, char ** argv, struct mpd_connection *conn )
+{
+	int ret;
+	struct mpd_status *status = mpd_run_status(conn);
+	if (status == NULL)
+		printErrorAndExit(conn);
+
+	const int from = mpd_status_get_queue_length(status);
+
+	ret = cmd_add(argc, argv, conn);
+	const int cur_pos = mpd_status_get_song_pos(status);
+	mpd_status_free(status);
+	if (ret != 0) {
+		return ret;
+	}
+	return mpd_run_move_range(conn, from, from+argc,
+		cur_pos+1);
+}
+
 int cmd_list ( int argc, char ** argv, struct mpd_connection *conn )
 {
 	enum mpd_tag_type type;
@@ -773,10 +792,10 @@ int cmd_volume ( int argc, char ** argv, struct mpd_connection *conn )
 		status = getStatus(conn);
 
 		if (mpd_status_get_volume(status) >= 0)
-			printf("volume:%3i%c   ",
+			printf("volume:%3i%c\n",
 			       mpd_status_get_volume(status), '%');
 		else
-			printf("volume: n/a   ");
+			printf("volume: n/a\n");
 
 		mpd_status_free(status);
 
@@ -797,7 +816,7 @@ int cmd_volume ( int argc, char ** argv, struct mpd_connection *conn )
 			ch.value = 100;
 
 		if (ch.value == old_volume)
-			return 0;
+			return 1;
 	}
 
 	if (!mpd_run_set_volume(conn, ch.value))
@@ -816,7 +835,7 @@ cmd_pause(mpd_unused int argc, mpd_unused char **argv, struct mpd_connection *co
 
 int cmd_repeat ( int argc, char ** argv, struct mpd_connection *conn )
 {
-	bool mode;
+	int mode;
 
 	if(argc==1) {
 		mode = get_boolean(argv[0]);
@@ -838,7 +857,7 @@ int cmd_repeat ( int argc, char ** argv, struct mpd_connection *conn )
 
 int cmd_random ( int argc, char ** argv, struct mpd_connection *conn )
 {
-	bool mode;
+	int mode;
 
 	if(argc==1) {
 		mode = get_boolean(argv[0]);
@@ -860,7 +879,7 @@ int cmd_random ( int argc, char ** argv, struct mpd_connection *conn )
 
 int cmd_single ( int argc, char ** argv, struct mpd_connection *conn )
 {
-	bool mode;
+	int mode;
 
 	if(argc==1) {
 		mode = get_boolean(argv[0]);
