@@ -45,6 +45,7 @@ int cmd_listall(int argc, char **argv, struct mpd_connection *conn);
 int cmd_ls(int argc, char **argv, struct mpd_connection *conn);
 int cmd_lsplaylists(int argc, char **argv, struct mpd_connection *conn);
 int cmd_load(int argc, char **argv, struct mpd_connection *conn);
+int cmd_insert(int argc, char **argv, struct mpd_connection *conn);
 int cmd_list(int argc, char **argv, struct mpd_connection *conn);
 int cmd_save(int argc, char **argv, struct mpd_connection *conn);
 int cmd_rm(int argc, char **argv, struct mpd_connection *conn);
@@ -70,4 +71,16 @@ int cmd_toggle(int argc, char **argv, struct mpd_connection *conn);
 int
 cmd_replaygain(int argc, char **argv, struct mpd_connection *conn);
 
+int
+cmd_channels(int argc, char **argv, struct mpd_connection *conn);
+
+int
+cmd_sendmessage(int argc, char **argv, struct mpd_connection *conn);
+
+int
+cmd_waitmessage(int argc, char **argv, struct mpd_connection *conn);
+
+int
+cmd_subscribe(int argc, char **argv, struct mpd_connection *conn);
+
 #endif /* COMMAND_H */
