@@ -28,6 +28,7 @@
 #include "command.h"
 #include "sticker.h"
 #include "idle.h"
+#include "message.h"
 #include "search.h"
 #include "mpc.h"
 #include "options.h"
@@ -81,6 +82,7 @@ static struct command {
 	{"ls",          0,   -1,  2,    cmd_ls,          "[<directory>]", "List the contents of <directory>"},
 	{"lsplaylists", 0,   -1,  2,    cmd_lsplaylists, "", "List currently available playlists"},
 	{"load",        0,   -1,  1,    cmd_load,        "<file>", "Load <file> as a playlist"},
+	{"insert",      0,   -1,  1,    cmd_insert,      "<file>", "Insert a song to the current playlist after the current track"},
 	{"save",        1,   1,   0,    cmd_save,        "<file>", "Save a playlist as <file>"},
 	{"rm",          1,   1,   0,    cmd_rm,          "<file>", "Remove a playlist"},
 	{"volume",      0,   1,   0,    cmd_volume,      "[+-]<num>", "Set volume to <num> or adjusts by [+-]<num>"},
@@ -103,7 +105,7 @@ static struct command {
 #endif
 	{"update",      0,   -1,  2,    cmd_update,      "[<path>]", "Scan music directory for updates"},
 #if LIBMPDCLIENT_CHECK_VERSION(2,1,0)
-	{"sticker",     1,   -1,  0,    cmd_sticker,     "<uri> <get|set|list|del> <args..>", "Sticker management"},
+	{"sticker",     2,   -1,  0,    cmd_sticker,     "<uri> <get|set|list|del> <args..>", "Sticker management"},
 #endif
 	{"stats",       0,   -1,  0,    cmd_stats,       "", "Display statistics about MPD"},
 	{"version",     0,   0,   0,    cmd_version,     "", "Report version of MPD"},
@@ -120,6 +122,17 @@ static struct command {
 	{ "replaygain", 0, -1, 0, cmd_replaygain, "[off|track|album]",
 	  "Set or display the replay gain mode" },
 
+#if LIBMPDCLIENT_CHECK_VERSION(2,5,0)
+	{ "channels", 0, 0, 0, cmd_channels, "",
+	  "List the channels that other clients have subscribed to." },
+	{ "sendmessage", 2, 2, 0, cmd_sendmessage, "<channel> <message>",
+	  "Send a message to the specified channel." },
+	{ "waitmessage", 1, 1, 0, cmd_waitmessage, "<channel>",
+	  "Wait for at least one message on the specified channel." },
+	{ "subscribe", 1, 1, 0, cmd_subscribe, "<channel>",
+	  "Subscribe to the specified channel and continuously receive messages." },
+#endif /* libmpdclient 2.5 */
+
 	/* don't remove this, when mpc_table[i].command is NULL it will terminate the loop */
 	{ .command = NULL }
 };
